user/dev discussion of public-inbox itself
 help / color / mirror / code / Atom feed
From: Eric Wong <e@80x24.org>
To: meta@public-inbox.org
Subject: [PATCH 22/38] view: html_footer: remove obuf dependency
Date: Sat, 10 Sep 2022 08:17:13 +0000	[thread overview]
Message-ID: <20220910081729.2011934-23-e@80x24.org> (raw)
In-Reply-To: <20220910081729.2011934-1-e@80x24.org>

Another step towards giving us more options for speedups and
memory reductions.
---
 lib/PublicInbox/View.pm | 12 ++++++------
 1 file changed, 6 insertions(+), 6 deletions(-)

diff --git a/lib/PublicInbox/View.pm b/lib/PublicInbox/View.pm
index b27523b2..40b4bf36 100644
--- a/lib/PublicInbox/View.pm
+++ b/lib/PublicInbox/View.pm
@@ -774,11 +774,12 @@ sub thread_skel ($$$) {
 	$ctx->{parent_msg} = $parent;
 }
 
-# appends to obuf
+# writes to zbuf
 sub html_footer {
 	my ($ctx, $hdr) = @_;
 	my $upfx = '../';
 	my ($related, $skel);
+	my $foot = '<pre>';
 	my $qry = delete $ctx->{-qry};
 	if ($qry && $ctx->{ibx}->isrch) {
 		my $q = ''; # search for either ancestor or descendent patches
@@ -836,15 +837,14 @@ EOF
 		} elsif ($u) { # unlikely
 			$parent = " <a\nhref=\"$u\"\nrel=prev>parent</a>";
 		}
-		${$ctx->{obuf}} .= "<pre>$next $prev$parent ";
+		$foot .= "$next $prev$parent ";
 	} else { # unindexed inboxes w/o over
-		${$ctx->{obuf}} .= '<pre>';
 		$skel = qq( <a\nhref="$upfx">latest</a>);
 	}
-	${$ctx->{obuf}} .= qq(<a\nhref="#R">reply</a>);
-	# $skel may be big for big threads, don't append it to obuf
+	$foot .= qq(<a\nhref="#R">reply</a>);
+	# $skel may be big for big threads, don't append it to $foot
 	$skel .= '</pre>' . ($related // '');
-	$ctx->zmore($skel .= msg_reply($ctx, $hdr)); # flushes obuf
+	$ctx->zmore($foot, $skel .= msg_reply($ctx, $hdr)); # flushes obuf
 }
 
 sub ghost_parent {

  parent reply	other threads:[~2022-09-10  8:18 UTC|newest]

Thread overview: 39+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2022-09-10  8:16 [PATCH 00/38] www: reduce memory usage Eric Wong
2022-09-10  8:16 ` [PATCH 01/38] xt: fold perf-obfuscate into perf-msgview, future-proof Eric Wong
2022-09-10  8:16 ` [PATCH 02/38] www: gzip_filter: implicitly flush {obuf} on zmore/zflush Eric Wong
2022-09-10  8:16 ` [PATCH 03/38] view: rework single message page to compress earlier Eric Wong
2022-09-10  8:16 ` [PATCH 04/38] www_atom_stream: require 200 response Eric Wong
2022-09-10  8:16 ` [PATCH 05/38] www_stream: aresponse assumes 200, too Eric Wong
2022-09-10  8:16 ` [PATCH 06/38] www_text: reduce parameter passing for response header Eric Wong
2022-09-10  8:16 ` [PATCH 07/38] viewvcs: use shorter and simpler ctx->html_done Eric Wong
2022-09-10  8:16 ` [PATCH 08/38] www_listing: consolidate some ->zmore dispatches Eric Wong
2022-09-10  8:17 ` [PATCH 09/38] www_listing: avoid unnecessary work for common cases Eric Wong
2022-09-10  8:17 ` [PATCH 10/38] www: viewdiff: use return value for diff_hunk Eric Wong
2022-09-10  8:17 ` [PATCH 11/38] view: simplify _parent_headers Eric Wong
2022-09-10  8:17 ` [PATCH 12/38] view: eml_entry: reduce manipulation of ctx->{obuf} Eric Wong
2022-09-10  8:17 ` [PATCH 13/38] gzip_filter: ->translate can reuse zmore/zflush Eric Wong
2022-09-10  8:17 ` [PATCH 14/38] view: remove multipart_text_as_html Eric Wong
2022-09-10  8:17 ` [PATCH 15/38] view: reduce subroutine calls for submsg_hdr Eric Wong
2022-09-10  8:17 ` [PATCH 16/38] view: attach_link: reduce obuf manipulation Eric Wong
2022-09-10  8:17 ` [PATCH 17/38] viewdiff: reuse existing string in diff_before_or_after Eric Wong
2022-09-10  8:17 ` [PATCH 18/38] view: _th_index_lite: avoid one s///, improve symmetry Eric Wong
2022-09-10  8:17 ` [PATCH 19/38] view: _th_index_lite: use `//' defined-or op Eric Wong
2022-09-10  8:17 ` [PATCH 20/38] view: reduce ascii_html calls and {obuf} use Eric Wong
2022-09-10  8:17 ` [PATCH 21/38] view: html_footer: golf out a few lines Eric Wong
2022-09-10  8:17 ` Eric Wong [this message]
2022-09-10  8:17 ` [PATCH 23/38] view: html_footer: avoid escaping " in a few places Eric Wong
2022-09-10  8:17 ` [PATCH 24/38] viewdiff: diff_hunk: shorten conditionals, slightly Eric Wong
2022-09-10  8:17 ` [PATCH 25/38] view: switch a few things to ctx->zmore Eric Wong
2022-09-10  8:17 ` [PATCH 26/38] www: drop {obuf} use entirely, for now Eric Wong
2022-09-10  8:17 ` [PATCH 27/38] www: switch to zadd for the majority of buffering Eric Wong
2022-09-10  8:17 ` [PATCH 28/38] www: use PerlIO::scalar (zfh) for buffering Eric Wong
2022-09-10  8:17 ` [PATCH 29/38] viewdiff: diff_before_or_after: avoid extra capture Eric Wong
2022-09-10  8:17 ` [PATCH 30/38] viewdiff: diff_header: shorten function, slightly Eric Wong
2022-09-10  8:17 ` [PATCH 31/38] www_static: switch to `print $zfh', and optimize Eric Wong
2022-09-10  8:17 ` [PATCH 32/38] httpd/async: describe which ->write subs it can call Eric Wong
2022-09-10  8:17 ` [PATCH 33/38] translate: support multiple buffer args Eric Wong
2022-09-10  8:17 ` [PATCH 34/38] gzip_filter: write: use multi-arg translate Eric Wong
2022-09-10  8:17 ` [PATCH 35/38] feed: new_html_i: switch from zmore to `print $zfh' Eric Wong
2022-09-10  8:17 ` [PATCH 36/38] mbox*: use multi-arg ->translate and ->write Eric Wong
2022-09-10  8:17 ` [PATCH 37/38] www_listing: switch to `print $zfh' Eric Wong
2022-09-10  8:17 ` [PATCH 38/38] viewvcs: " Eric Wong

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

  List information: https://public-inbox.org/README

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20220910081729.2011934-23-e@80x24.org \
    --to=e@80x24.org \
    --cc=meta@public-inbox.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
Code repositories for project(s) associated with this public inbox

	https://80x24.org/public-inbox.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).